==> cohesity_management_sdk-1.0.0.tar.gz: cohesity_management_sdk-1.0.0/cohesity_management_sdk/models/metric_data_point.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

import cohesity_management_sdk.models.data

class MetricDataPoint(object):

    """Implementation of the 'Metric Data Point.' model.

    Specifies information about a single data point in a time series.

    Attributes:
        data (Data): Specifies the fields to store data of a given type.
            Specify data in the appropriate field for the current data type.
        timestamp_msecs (long|int): Specifies a timestamp when the metric data
            point was captured.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data":'data',
        "timestamp_msecs":'timestampMsecs'
    }

    def __init__(self,
                 data=None,
                 timestamp_msecs=None):
        """Constructor for the MetricDataPoint class"""

        # Initialize members of the class
        self.data = data
        self.timestamp_msecs = timestamp_msecs


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        data = cohesity_management_sdk.models.data.Data.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
        timestamp_msecs = dictionary.get('timestampMsecs')

        # Return an object of this model
        return cls(data,
                   timestamp_msecs)

==> cohesity_management_sdk-1.1.3.tar.gz: cohesity_management_sdk-1.1.3/cohesity_management_sdk/models/metric_data_point.py <==
# -*- coding: utf-8 -*-
# Copyright 2019 Cohesity Inc.

import cohesity_management_sdk.models.value_data

class MetricDataPoint(object):

    """Implementation of the 'MetricDataPoint' model.

    Specifies information about a single data point in a time series.

    Attributes:
        data (ValueData): Specifies the fields to store data of a given type.
            Specify data in the appropriate field for the current data type.
        timestamp_msecs (long|int): Specifies a timestamp when the metric data
            point was captured.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "data":'data',
        "timestamp_msecs":'timestampMsecs'
    }

    def __init__(self,
                 data=None,
                 timestamp_msecs=None):
        """Constructor for the MetricDataPoint class"""

        # Initialize members of the class
        self.data = data
        self.timestamp_msecs = timestamp_msecs


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        data = cohesity_management_sdk.models.value_data.ValueData.from_dictionary(dictionary.get('data')) if dictionary.get('data') else None
        timestamp_msecs = dictionary.get('timestampMsecs')

        # Return an object of this model
        return cls(data,
                   timestamp_msecs)
